@@ -2,7 +2,7 @@
 
 #
 # DaVinci Resolve 16.2.2 Debian package creator
-# Release 2020-05-19
+# Release 2020-05-20
 # By Daniel Tufvesson
 #
 
@@ -63,7 +63,7 @@ make_executable() {
 
 # Setup variables
 RESOLVE_VERSION=16.2.2
-DEB_STEPPING=1
+DEB_STEPPING=2
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -150,8 +150,8 @@ SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="066
 EOF
 
 # Extract panel API library
-create_directory ${DEB_DIR}/usr/lib
-extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libDaVinciPanelAPI.so
+create_directory ${DEB_DIR}/usr/lib/x86_64-linux-gnu
+extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/x86_64-linux-gnu libDaVinciPanelAPI.so
 
 # Create symlinks
 create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
@@ -194,9 +194,20 @@ chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.license
 chmod -R a+rw /opt/resolve/Fairlight
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
+test ! -e /usr/lib64 && mkdir /usr/lib64 && touch /usr/lib64.by.makeresolvedeb
+test ! -h /usr/lib64/libDaVinciPanelAPI.so && ln -s /usr/lib/x86_64-linux-gnu/libDaVinciPanelAPI.so /usr/lib64/libDaVinciPanelAPI.so
+test ! -h /usr/lib/libDaVinciPanelAPI.so && ln -s /usr/lib/x86_64-linux-gnu/libDaVinciPanelAPI.so /usr/lib/libDaVinciPanelAPI.so
 exit 0
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
+cat > ${DEB_DIR}/DEBIAN/postrm <<EOF
+#!/bin/sh
+test -h /usr/lib/libDaVinciPanelAPI.so && rm /usr/lib/libDaVinciPanelAPI.so
+test -h /usr/lib64/libDaVinciPanelAPI.so && rm /usr/lib64/libDaVinciPanelAPI.so
+test -e /usr/lib64.by.makeresolvedeb && rmdir /usr/lib64 && rm /usr/lib64.by.makeresolvedeb
+exit 0
+EOF
+make_executable ${DEB_DIR}/DEBIAN/postrm
 check_command fakeroot
 check_command dpkg-deb
 fakeroot dpkg-deb -b ${DEB_DIR} ${DEB_DIR}.deb
